==> hu35ksubc_1.10.0.tar.gz: hu35ksubc/man/hu35ksubcOMIM.Rd <==
\name{hu35ksubcOMIM}
\alias{hu35ksubcOMIM}
\title{Map between Manufacturer Identifiers and Mendelian Inheritance in
  Man (MIM) identifiers}
\description{
  hu35ksubcOMIM is an R environment that provides mappings between
  manufacturer ids and OMIM ids.
}
\details{
  Each manufacturer id is mapped to a vector of OMIM ids. The vector
  length may be one or longer, depending on how many OMIM ids the
  manufacturer id maps to. An \code{NA} is reported for any manufacturer
  id that cannot be mapped to an OMIM id at this time.
  
  OMIM is based upon the book Mendelian Inheritance in Man
  (V. A. McKusick) and focuses primarily on inherited or heritable
  genetic diseases. It contains textual information, pictures, and reference
  information that can be searched using various terms, among which the
  MIM number is one. 
  
  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Wed Oct 12 14:17:23 2005

  Package built Wed Oct 12 14:30:40 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
  \url{http://www3.ncbi.nlm.nih.gov/entrez/query.fcgi?db=OMIM}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hu35ksubcOMIM)
    # Remove probe ids that do not map to any MIM number
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The MIM numbers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    }
}

\keyword{datasets}

==> hu35ksubc_1.12.0.tar.gz: hu35ksubc/man/hu35ksubcOMIM.Rd <==
\name{hu35ksubcOMIM}
\alias{hu35ksubcOMIM}
\title{Map between Manufacturer Identifiers and Mendelian Inheritance in
  Man (MIM) identifiers}
\description{
  hu35ksubcOMIM is an R environment that provides mappings between
  manufacturer ids and OMIM ids.
}
\details{
  Each manufacturer id is mapped to a vector of OMIM ids. The vector
  length may be one or longer, depending on how many OMIM ids the
  manufacturer id maps to. An \code{NA} is reported for any manufacturer
  id that cannot be mapped to an OMIM id at this time.
  
  OMIM is based upon the book Mendelian Inheritance in Man
  (V. A. McKusick) and focuses primarily on inherited or heritable
  genetic diseases. It contains textual information, pictures, and reference
  information that can be searched using various terms, among which the
  MIM number is one. 
  
  Mappings were based on data provided by:

  Entrez Gene:\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Sun Mar 26 03:41:51 2006

  Package built Sun Mar 26 03:56:42 2006
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
  \url{http://www3.ncbi.nlm.nih.gov/entrez/query.fcgi?db=OMIM}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hu35ksubcOMIM)
    # Remove probe ids that do not map to any MIM number
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The MIM numbers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    }
}

\keyword{datasets}
